@@ -8,9 +8,8 @@ def enable_logger(level):
   logger.enable("fastsubtrees")
   msgformat_prefix="<green><dim>{time:YYYY-MM-DD HH:mm:ss}</></>"
   msgformat_content="<level><normal>{level.name}: {message}</></>"
-  logger.add(sys.stderr,
-        format=f"{msgformat_prefix} {msgformat_content}",
-               level=level)
+  logger.add(sys.stderr, format=f"{msgformat_prefix} {msgformat_content}",
+             level=level)
 
 # create a flag to enable/disable progress bar; disable it by default;
 # the method tqdm will respect this flag and behave like tqdm.tqdm;
@@ -21,4 +20,4 @@ tqdm = lambda *args, **kargs: \
 
 from fastsubtrees.error import *
 from fastsubtrees.tree import Tree
-
+from fastsubtrees.attribute import *
